#pragma once
#include "def.h"
#include "physics.h"
#include "ship.h"

#define PILOT_PLAYER    1 // Pilot is a player.

struct Pilot {
  unsigned int id; // Pilots id.
  char* name;     // Pilot's name (if unique).

  Ship* ship;     // Pilots ship.
  Solid* solid;   // Associated solid (physics).

  // Current health.
  FP armor, shield, energy;

  void (*update)(struct Pilot*, const FP); // Update the pilot.
  void (*think)(struct Pilot*); // AI thinking for the pilot.

  unsigned int properties; // Used for AI etc.
};
typedef struct Pilot Pilot;

extern Pilot* player; // The player.
Pilot* get_pilot(unsigned int id);

// Creation.
void pilot_init(Pilot* dest, Ship* ship, char* name,
      const Vec2* vel, const Vec2* pos, const int flags);

unsigned int pilot_create(Ship* ship, char* name, const Vec2* vel,
      const Vec2* pos, const int flags);

// Cleanup.
void pilot_free(void);

// Update.
void pilots_update(FP dt);

